@@ -803,6 +803,12 @@ class Document(dict):
         if '_db' in kwargs:
             self._db = kwargs['_db']
             del(kwargs['_db'])
+
+        # for subclassing (when __init__ receives Document as first argument), pass _db to result class
+        if len(args) and isinstance(args[0], Document):
+            if hasattr(args[0], '_db'):
+                self._db = args[0]._db
+            
         dict.__init__(self, *args, **kwargs)
     
     def __repr__(self):
@@ -837,7 +843,7 @@ class Document(dict):
 
     def __setattr__(self, name, value):
         if name == '_db':
-            super(mydict, self).__setattr__(name, value)
+            super(Document, self).__setattr__(name, value)
         else:
             self[name] = value
 
